Allocation Functions
====================

Below are example allocation functions available in libEnsemble.

.. IMPORTANT::
  See the API for allocation functions :ref:`here<api_alloc_f>`.

.. note:: The default alloc_func is give_sim_work_first.

.. _gswf_label:

give_sim_work_first
-------------------
.. automodule:: give_sim_work_first
  :members:
  :undoc-members:

fast_alloc
----------
.. automodule:: fast_alloc
  :members:
  :undoc-members:

fast_alloc_to_aposmm
--------------------
.. automodule:: fast_alloc_to_aposmm
  :members:
  :undoc-members:

.. _start_only_persistent_label:

start_only_persistent
---------------------
.. automodule:: start_only_persistent
  :members:
  :undoc-members:

start_persistent_local_opt_gens
-------------------------------
.. automodule:: start_persistent_local_opt_gens
  :members:
  :undoc-members:
